@@ -17,12 +17,11 @@ use HTTP::Request::Common;
 use Log::Any ();
 use Cache::LRU;
 use Clone qw(clone);
-use Data::Dumper;
 use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -622,8 +621,7 @@ RDF::LDF - Linked Data Fragments client
 
 =head1 DESCRIPTION
 
-The RDF::LDF  module is a basic implementation of a Linked Data Fragment client. For details see:
-<http://linkeddatafragments.org/>.
+RDF::LDF implements a basic L<Linked Data Fragment|http://linkeddatafragments.org/> client.
 
 This a low level module to implement the Linked Data Fragment protocol. You probably want to
 use L<RDF::Trine::Store::LDF>.
